Learn R Programming

excessmort (version 0.8.2)

excess_cumulative: Compute cumulative excess deaths

Description

This function takes the output of the `excess_model` function, a start date, and end date and calculates excess mortality and standard errors.

Usage

excess_cumulative(fit, start, end)

Value

A data frame with the following columns

date

The date

observed

The observed excess mortality,which is the sum of observed minus expected until that date

sd

The standard deviation for excess mortality for that date if year is typical

fitted

The estimated of excess mortality based on the estimated smooth event effect curve

se

The standard error for `fitted`

Arguments

fit

The output of `excess_model`

start

The start date

end

The end date

Examples

Run this code

data(new_jersey_counts)
exclude_dates <- as.Date("2012-10-29") + 0:180
control_dates <- seq(min(new_jersey_counts$date), min(exclude_dates) - 1, by = "day")
f <- excess_model(new_jersey_counts, 
start = as.Date("2012-09-01"), 
end = as.Date("2013-09-01"),
exclude = exclude_dates,
model = "correlated",
weekday.effect = TRUE,
control.dates = control_dates)

excess_cumulative(f, 
start = as.Date("2017-12-15"), 
end = as.Date("2017-12-21") )

Run the code above in your browser using DataLab