A data frame with Louisiana daily mortality counts from 2003-01-01 to 2016-12-31,
which includes the day Katrina made landfall on 2015-08-29.
The outcome column includes the number of deaths for that day.
Usage
data("louisiana_counts")
Arguments
Format
An object of class tbl_df (inherits from tbl, data.frame) with 1461 rows and 3 columns.