Learn R Programming

excessmort (version 0.8.2)

puerto_rico_icd: Puerto Rico daily mortality by cause of death

Description

A data frame with Puerto Rico daily mortality counts, stratified by cause of death from 1999 to 2020. which includes the day hurricanes Maria made landfall on 2017-09-20. The outcome column includes the number of deaths for that day for that ICD-10 code. The object `icd` is included to show the description of each ICD-10 code.

Usage

data("puerto_rico_icd")

Arguments

Format

An object of class tbl_df (inherits from tbl, data.frame) with 262980 rows and 4 columns.